@@ -96,7 +96,7 @@ tab_df <- function(x,
                    footnote = NULL,
                    col.header = NULL,
                    show.type = FALSE,
-                   show.rownames = TRUE,
+                   show.rownames = FALSE,
                    show.footnote = FALSE,
                    alternate.rows = FALSE,
                    sort.column = NULL,
@@ -113,12 +113,12 @@ tab_df <- function(x,
   # get style definition
   style <- tab_df_style(CSS = CSS, ...)
 
-  x <- purrr::map_df(x, function(.i) {
+  x <- as.data.frame(lapply(x, function(.i) {
     if (is.numeric(.i) && sjmisc::is_float(.i))
       sprintf("%.*f", digits, .i)
     else
       .i
-  })
+  }))
 
   # get HTML content
   page.content <- tab_df_content(
@@ -175,10 +175,11 @@ tab_dfs <- function(x,
                     footnotes = NULL,
                     col.header = NULL,
                     show.type = FALSE,
-                    show.rownames = TRUE,
+                    show.rownames = FALSE,
                     show.footnote = FALSE,
                     alternate.rows = FALSE,
                     sort.column = NULL,
+                    digits = 2,
                     encoding = "UTF-8",
                     CSS = NULL,
                     file = NULL,
@@ -206,6 +207,13 @@ tab_dfs <- function(x,
   # get HTML content
   page.content <- paste(
       purrr::flatten_chr(purrr::pmap(list(x, titles, footnotes), function(dat, title, footnote) {
+        dat[] <- lapply(dat, function(.i) {
+          if (is.numeric(.i) && sjmisc::is_float(.i))
+            sprintf("%.*f", digits, .i)
+          else
+            .i
+        })
+
         tab_df_content(
           mydf = dat,
           title = title,
@@ -277,6 +285,7 @@ tab_model_df <- function(x,
                          col.header = NULL,
                          show.re.var = FALSE,
                          show.icc = FALSE,
+                         digits.re = 2,
                          encoding = "UTF-8",
                          CSS = NULL,
                          file = NULL,
@@ -313,18 +322,33 @@ tab_model_df <- function(x,
     sort.column = NULL,
     include.table.tag = FALSE,
     no.last.table.row = TRUE,
+    zeroinf = is.zeroinf,
     ...
   )
 
+  # do we have labels for dependent variables / models?
+
+  empty_dv <- is.null(dv.labels) | (length(dv.labels) == 1 && dv.labels == "")
+
   # replace CSS for first table row
 
-  page.content <- gsub(
-    pattern = "thead ",
-    replacement = "depvarhead ",
-    x = page.content,
-    fixed = TRUE,
-    useBytes = TRUE
-  )
+  if (!empty_dv) {
+    page.content <- gsub(
+      pattern = "thead ",
+      replacement = "depvarhead ",
+      x = page.content,
+      fixed = TRUE,
+      useBytes = TRUE
+    )
+  } else {
+    page.content <- gsub(
+      pattern = "thead ",
+      replacement = "depvarheadnodv ",
+      x = page.content,
+      fixed = TRUE,
+      useBytes = TRUE
+    )
+  }
 
   # replace HTML-Tag for first table row
 
@@ -347,20 +371,22 @@ tab_model_df <- function(x,
 
   # table column header, with label of dependent variables ----
 
-  dv.content <- "  <tr>\n"
-  dv.content <- paste0(dv.content, "    <th class=\"thead firsttablerow firsttablecol col1\">&nbsp;</th>\n")
+  if (!empty_dv) {
+    dv.content <- "  <tr>\n"
+    dv.content <- paste0(dv.content, "    <th class=\"thead firsttablerow firsttablecol col1\">&nbsp;</th>\n")
 
-  for (i in 1:length(dv.labels)) {
-    colspan <- length(string_ends_with(sprintf("_%i", i), x = colnames(x)))
-    dv.content <- paste0(
-      dv.content,
-      sprintf("    <th colspan=\"%i\" class=\"thead firsttablerow\">%s</th>\n", colspan, dv.labels[i])
-    )
+    for (i in 1:length(dv.labels)) {
+      colspan <- length(string_ends_with(sprintf("_%i", i), x = colnames(x)))
+      dv.content <- paste0(
+        dv.content,
+        sprintf("    <th colspan=\"%i\" class=\"thead firsttablerow\">%s</th>\n", colspan, dv.labels[i])
+      )
+    }
+
+    dv.content <- paste0(dv.content, "  </tr>\n")
+    page.content <- paste0(dv.content, page.content)
   }
 
-  dv.content <- paste0(dv.content, "  </tr>\n")
-  page.content <- paste0(dv.content, page.content)
-
 
   # simplex parameters here ----
 
@@ -389,7 +415,7 @@ tab_model_df <- function(x,
     )
 
     page.content <- paste0(page.content, "  <tr>\n")
-    page.content <- paste0(page.content, sprintf("    <td colspan=\"%i\" class=\"simplexparts\">Simplex Parameters</td>\n", ncol(x)))
+    page.content <- paste0(page.content, sprintf("    <td colspan=\"%i\" class=\"simplexparts\">Monotonic Effects</td>\n", ncol(x)))
     page.content <- paste0(page.content, "  </tr>\n")
 
     page.content <- paste0(page.content, sp.content)
@@ -426,6 +452,7 @@ tab_model_df <- function(x,
       sort.column = NULL,
       include.table.tag = FALSE,
       no.last.table.row = TRUE,
+      zeroinf = FALSE,
       ...
     )
 
@@ -472,9 +499,10 @@ tab_model_df <- function(x,
         page.content <- paste0(
           page.content,
           sprintf(
-            "    <td class=\"%s\" colspan=\"%i\">%.2f</td>\n",
+            "    <td class=\"%s\" colspan=\"%i\">%.*f</td>\n",
             s_css,
             as.integer(colspan),
+            digits.re,
             variance.list[[i]]$var.residual
           )
         )
@@ -497,7 +525,8 @@ tab_model_df <- function(x,
         clean.rv = "tau.00",
         var.names = colnames(x),
         summary.css = summary.css,
-        n.cols = ncol(x)
+        n.cols = ncol(x),
+        digits.re = digits.re
     ))
 
 
@@ -519,7 +548,8 @@ tab_model_df <- function(x,
           clean.rv = "tau.11",
           var.names = colnames(x),
           summary.css = summary.css,
-          n.cols = ncol(x)
+          n.cols = ncol(x),
+          digits.re = digits.re
       ))
 
       rho01 <- purrr::map(variance.list, ~ .x$cor.slope_intercept)
@@ -534,7 +564,8 @@ tab_model_df <- function(x,
           clean.rv = "rho.01",
           var.names = colnames(x),
           summary.css = summary.css,
-          n.cols = ncol(x)
+          n.cols = ncol(x),
+          digits.re = digits.re
       ))
 
     }
@@ -556,7 +587,8 @@ tab_model_df <- function(x,
         var.names = colnames(x),
         summary.css = summary.css,
         n.cols = ncol(x),
-        delim = ".adjusted"
+        delim = ".adjusted",
+        digits.re = digits.re
       ))
 
   }
@@ -825,7 +857,7 @@ tab_model_df <- function(x,
 }
 
 
-create_random_effects <- function(rv.len, rv, rv.string, clean.rv, var.names, summary.css, n.cols, delim = "_", as_int = FALSE) {
+create_random_effects <- function(rv.len, rv, rv.string, clean.rv, var.names, summary.css, n.cols, delim = "_", as_int = FALSE, digits.re = 2) {
   page.content <- ""
   pattern <- paste0("^", clean.rv, delim)
 
@@ -884,9 +916,10 @@ create_random_effects <- function(rv.len, rv, rv.string, clean.rv, var.names, su
           page.content <- paste0(
             page.content,
             sprintf(
-              "    <td class=\"%s\" colspan=\"%i\">%.2f%s</td>\n",
+              "    <td class=\"%s\" colspan=\"%i\">%.*f%s</td>\n",
               s_css,
               as.integer(colspan),
+              digits.re,
               rv[[j]][i],
               suffix
             )
