@@ -16,9 +16,9 @@
 #'     only contains one predictor, slope-line is plotted.}
 #'     \item{\code{type = "re"}}{For mixed effects models, plots the random
 #'     effects.}
-#'     \item{\code{type = "std"}}{Forest-plot of standardized beta values.}
-#'     \item{\code{type = "std2"}}{Forest-plot of standardized beta values,
-#'     however, standardization is done by dividing by two sd (see 'Details').}
+#'     \item{\code{type = "std"}}{Forest-plot of standardized coefficients.}
+#'     \item{\code{type = "std2"}}{Forest-plot of standardized coefficients,
+#'     however, standardization is done by dividing by two SD (see 'Details').}
 #'   }
 #'   \emph{Marginal Effects}  (\href{https://strengejacke.github.io/sjPlot/articles/plot_marginal_effects.html}{related vignette})
 #'   \describe{
@@ -131,7 +131,7 @@
 #'   popularized by Aiken and West (1991), i.e. using the mean, the value one
 #'   standard deviation above, and the value one standard deviation below the
 #'   mean as values of the moderator, see
-#'   \href{http://www.theanalysisfactor.com/3-tips-interpreting-moderation/}{Grace-Martin
+#'   \href{https://www.theanalysisfactor.com/3-tips-interpreting-moderation/}{Grace-Martin
 #'   K: 3 Tips to Make Interpreting Moderation Effects Easier}).}
 #'   \item{\code{"zeromax"}}{is similar to the \code{"minmax"} option, however,
 #'   \code{0} is always used as minimum value for the moderator. This may be
@@ -146,7 +146,7 @@
 #'   \code{\link[lme4]{ranef}}) will be plotted. Default is \code{NULL}, so all
 #'   random effects will be plotted.
 #' @param title Character vector, used as plot title. By default,
-#'   \code{\link[sjlabelled]{get_dv_labels}} is called to retrieve the label of
+#'   \code{\link[sjlabelled]{response_labels}} is called to retrieve the label of
 #'   the dependent variable, which will be used as title. Use \code{title = ""}
 #'   to remove title.
 #' @param axis.title Character vector of length one or two (depending on the
@@ -157,7 +157,7 @@
 #'   \code{\link[ggplot2]{labs}}. Use \code{axis.title = ""} to remove axis
 #'   titles.
 #' @param axis.labels Character vector with labels for the model terms, used as
-#'   axis labels. By default, \code{\link[sjlabelled]{get_term_labels}} is
+#'   axis labels. By default, \code{\link[sjlabelled]{term_labels}} is
 #'   called to retrieve the labels of the coefficients, which will be used as
 #'   axis labels. Use \code{axis.labels = ""} or \code{auto.label = FALSE} to
 #'   use the variable names as labels instead. If \code{axis.labels} is a named
@@ -188,10 +188,11 @@
 #' @param se Logical, if \code{TRUE}, the standard errors are
 #'   also printed. If robust standard errors are required, use arguments
 #'   \code{vcov.fun}, \code{vcov.type} and \code{vcov.args} (see
-#'   \code{\link[sjstats]{robust}} for details). \code{se} overrides
-#'   \code{ci.lvl}: if not \code{NULL}, arguments \code{ci.lvl}
-#'   and \code{transform} will be ignored. Currently, \code{se} only applies
-#'   to \emph{Coefficients} plots.
+#'   \code{\link[parameters]{standard_error_robust}} and
+#'   \href{https://easystats.github.io/parameters/articles/model_parameters_robust.html}{this vignette}
+#'   for details), or use argument \code{robust} as shortcut. \code{se} overrides
+#'   \code{ci.lvl}: if not \code{NULL}, arguments \code{ci.lvl} and \code{transform}
+#'   will be ignored. Currently, \code{se} only applies to \emph{Coefficients} plots.
 #' @param show.intercept Logical, if \code{TRUE}, the intercept of the fitted
 #'   model is also plotted. Default is \code{FALSE}. If \code{transform =
 #'   "exp"}, please note that due to exponential transformation of estimates,
@@ -205,12 +206,18 @@
 #'   legend.
 #' @param show.zeroinf Logical, if \code{TRUE}, shows the zero-inflation part of
 #'   hurdle- or zero-inflated models.
+#' @param robust Logical, shortcut for arguments \code{vcov.fun} and \code{vcov.type}.
+#'   If \code{TRUE}, uses \code{vcov.fun = "vcovHC"} and \code{vcov.type = "HC3"} as
+#'   default, that is, \code{\link[sandwich]{vcovHC}} with default-type is called
+#'   (see \code{\link[parameters]{standard_error_robust}} and
+#'   \href{https://easystats.github.io/parameters/articles/model_parameters_robust.html}{this vignette}
+#'   for further details).
 #' @param vcov.fun Character vector, indicating the name of the \code{vcov*()}-function
-#'    from the \pkg{sandwich}-package, e.g. \code{vcov.fun = "vcovCL"}, if robust
-#'    standard errors are required.
+#'    from the \pkg{sandwich} or \pkg{clubSandwich} package, e.g. \code{vcov.fun = "vcovCL"},
+#'    if robust standard errors are required.
 #' @param vcov.type Character vector, specifying the estimation type for the
-#'    robust covariance matrix estimation (see \code{\link[sandwich]{vcovHC}}
-#'    for details).
+#'    robust covariance matrix estimation (see \code{\link[sandwich:vcovHC]{vcovHC()}}
+#'    or \code{clubSandwich::vcovCR()} for details).
 #' @param vcov.args List of named vectors, used as additional arguments that
 #'    are passed down to \code{vcov.fun}.
 #' @param value.offset Numeric, offset for text labels to adjust their position
@@ -224,7 +231,7 @@
 #'     \item If not specified, a default color brewer palette will be used, which is suitable for the plot style.
 #'     \item If \code{"gs"}, a greyscale will be used.
 #'     \item If \code{"bw"}, and plot-type is a line-plot, the plot is black/white and uses different line types to distinguish groups (see \href{https://strengejacke.github.io/sjPlot/articles/blackwhitefigures.html}{this package-vignette}).
-#'     \item If \code{colors} is any valid color brewer palette name, the related palette will be used. Use \code{\link[RColorBrewer]{display.brewer.all}} to view all available palette names.
+#'     \item If \code{colors} is any valid color brewer palette name, the related palette will be used. Use \code{RColorBrewer::display.brewer.all()} to view all available palette names.
 #'     \item There are some pre-defined color palettes in this package, see \code{\link{sjPlot-themes}} for details.
 #'     \item Else specify own color values or names as vector (e.g. \code{colors = "#00ff00"} or \code{colors = c("firebrick", "blue")}).
 #'   }
@@ -238,7 +245,7 @@
 #' @param wrap.labels Numeric, determines how many chars of the value, variable
 #'   or axis labels are displayed in one line and when a line break is inserted.
 #' @param case Desired target case. Labels will automatically converted into the
-#'   specified character case. See \code{\link[snakecase]{to_any_case}} for more
+#'   specified character case. See \code{snakecase::to_any_case()} for more
 #'   details on this argument. By default, if \code{case} is not specified,
 #'   it will be set to \code{"parsed"}, unless \code{prefix.labels} is not
 #'   \code{"none"}. If \code{prefix.labels} is either \code{"label"} (or
@@ -247,14 +254,14 @@
 #'   default when prefixing labels.
 #' @param auto.label Logical, if \code{TRUE} (the default),
 #'    and \href{https://strengejacke.github.io/sjlabelled/articles/intro_sjlabelled.html}{data is labelled},
-#'    \code{\link[sjlabelled]{get_term_labels}} is called to retrieve the labels
+#'    \code{\link[sjlabelled]{term_labels}} is called to retrieve the labels
 #'    of the coefficients, which will be used as predictor labels. If data is
 #'    not labelled, \href{https://easystats.github.io/parameters/reference/format_parameters.html}{format_parameters()}
 #'    is used to create pretty labels. If \code{auto.label = FALSE},
 #'   original variable names and value labels (factor levels) are used.
 #' @param prefix.labels Indicates whether the value labels of categorical variables
 #'   should be prefixed, e.g. with the variable name or variable label. See
-#'   argument \code{prefix} in \code{\link[sjlabelled]{get_term_labels}} for
+#'   argument \code{prefix} in \code{\link[sjlabelled]{term_labels}} for
 #'   details.
 #' @param jitter Numeric, between 0 and 1. If \code{show.data = TRUE}, you can
 #'   add a small amount of random variation to the location of each data point.
@@ -262,6 +269,8 @@
 #'   will be occupied by the jittered values.
 #' @param digits Numeric, amount of digits after decimal point when rounding
 #'   estimates or values.
+#' @param p.adjust Character vector, if not \code{NULL}, indicates the method
+#'   to adjust p-values. See \code{\link[stats]{p.adjust}} for details.
 #' @param value.size Numeric, indicates the size of value labels. Can be used
 #'   for all plot types where the argument \code{show.values} is applicable,
 #'   e.g. \code{value.size = 4}.
@@ -318,7 +327,7 @@
 #'     }
 #'     \item{Case conversion of labels}{For case conversion of labels (see argument
 #'       \code{case}), arguments \code{sep_in} and \code{sep_out} will be passed
-#'       down to \code{\link[snakecase]{to_any_case}}. This only
+#'       down to \code{snakecase::to_any_case()}. This only
 #'       applies to automatically retrieved term labels, \emph{not} if
 #'       term labels are provided by the \code{axis.labels}-argument.
 #'     }
@@ -331,23 +340,21 @@
 #'   (depending on the plot-type) a list of such data frames.
 #'
 #' @details
-#'   \code{get_model_data()} simply calls \code{plot_model()} and returns
-#'   the data from the ggplot-object. Hence, it is rather inefficient and should
-#'   be used as alternative to \pkg{brooms} \code{tidy()}-function only in
-#'   specific situations. \cr \cr Some details on the different plot-types:
+#' \subsection{Different Plot Types}{
 #'   \describe{
-#'   \item{\code{type = "std2"}}{Plots standardized beta values,
-#'     however, standardization follows Gelman's (2008) suggestion, rescaling the
+#'   \item{\code{type = "std"}}{Plots standardized estimates. See details below.}
+#'   \item{\code{type = "std2"}}{Plots standardized estimates, however,
+#'     standardization follows Gelman's (2008) suggestion, rescaling the
 #'     estimates by dividing them by two standard deviations instead of just one.
 #'     Resulting coefficients are then directly comparable for untransformed
 #'     binary predictors.
 #'   }
-#'   \item{\code{type = "pred"}}{Plots marginal effects. Simply wraps
-#'     \code{\link[ggeffects]{ggpredict}}. See also
+#'   \item{\code{type = "pred"}}{Plots estimated marginal means (or marginal effects).
+#'     Simply wraps \code{\link[ggeffects]{ggpredict}}. See also
 #'     \href{https://strengejacke.github.io/sjPlot/articles/plot_marginal_effects.html}{this package-vignette}.
 #'   }
-#'   \item{\code{type = "eff"}}{Plots marginal effects. Simply wraps
-#'     \code{\link[ggeffects]{ggeffect}}. See also
+#'   \item{\code{type = "eff"}}{Plots estimated marginal means (or marginal effects).
+#'     Simply wraps \code{\link[ggeffects]{ggeffect}}. See also
 #'     \href{https://strengejacke.github.io/sjPlot/articles/plot_marginal_effects.html}{this package-vignette}.
 #'   }
 #'   \item{\code{type = "int"}}{A shortcut for marginal effects plots, where
@@ -378,9 +385,21 @@
 #'   multicollinearity-check (Variance Inflation Factors), QQ-plots,
 #'   checks for normal distribution of residuals and homoscedasticity
 #'   (constant variance of residuals) are shown. For \strong{generalized
-#'   lineare mixed models}, returns the QQ-plot for random effects.
+#'   linear mixed models}, returns the QQ-plot for random effects.
 #'   }
 #'   }
+#' }
+#' \subsection{Standardized Estimates}{
+#'   Default standardization is done by completely refitting the model on the
+#'   standardized data. Hence, this approach is equal to standardizing the
+#'   variables before fitting the model, which is particularly recommended for
+#'   complex models that include interactions or transformations (e.g., polynomial
+#'   or spline terms). When \code{type = "std2"}, standardization of estimates
+#'   follows \href{http://www.stat.columbia.edu/~gelman/research/published/standardizing7.pdf}{Gelman's (2008)}
+#'   suggestion, rescaling the estimates by dividing them by two standard deviations
+#'   instead of just one. Resulting coefficients are then directly comparable for
+#'   untransformed binary predictors.
+#' }
 #'
 #' @references
 #'   Gelman A (2008) "Scaling regression inputs by dividing by two
@@ -448,7 +467,7 @@
 #'
 #' @importFrom insight model_info find_predictors
 #' @importFrom sjmisc word_wrap str_contains
-#' @importFrom sjlabelled get_dv_labels get_term_labels
+#' @importFrom sjlabelled response_labels term_labels
 #' @importFrom dplyr if_else n_distinct
 #' @importFrom graphics plot
 #' @importFrom ggeffects ggpredict ggeffect
@@ -476,6 +495,7 @@ plot_model <- function(model,
                        grid.breaks = NULL,
                        ci.lvl = NULL,
                        se = NULL,
+                       robust = FALSE,
                        vcov.fun = NULL,
                        vcov.type = c("HC3", "const", "HC", "HC0", "HC1", "HC2", "HC4", "HC4m", "HC5"),
                        vcov.args = NULL,
@@ -494,6 +514,7 @@ plot_model <- function(model,
                        line.size = NULL,
                        vline.color = NULL,
                        p.threshold = c(0.05, 0.01, 0.001),
+                       p.adjust = NULL,
                        grid,
                        case,
                        auto.label = TRUE,
@@ -521,6 +542,11 @@ plot_model <- function(model,
       case <- NULL
   }
 
+  if (isTRUE(robust)) {
+    vcov.type <- "HC3"
+    vcov.fun <- "vcovHC"
+  }
+
   # check se-argument
   vcov.fun <- check_se_argument(se = vcov.fun, type = type)
 
@@ -549,12 +575,12 @@ plot_model <- function(model,
   if (type %in% c("est", "std", "std2") && isTRUE(auto.label)) {
 
     # get labels of dependent variables, and wrap them if too long
-    if (is.null(title)) title <- sjlabelled::get_dv_labels(model, case = case, mv = fam.info$is_multivariate, ...)
+    if (is.null(title)) title <- sjlabelled::response_labels(model, case = case, mv = fam.info$is_multivariate, ...)
     title <- sjmisc::word_wrap(title, wrap = wrap.title)
 
     # labels for axis with term names
     if (is.null(axis.labels)) {
-      term_labels <- sjlabelled::get_term_labels(model, case = case, prefix = prefix.labels, ...)
+      term_labels <- sjlabelled::term_labels(model, case = case, prefix = prefix.labels, ...)
       if (.labelled_model_data(model) || is.stan(model)) axis.labels <- term_labels
     }
     axis.labels <- sjmisc::word_wrap(axis.labels, wrap = wrap.labels)
@@ -640,6 +666,7 @@ plot_model <- function(model,
       vcov.type = vcov.type,
       vcov.args = vcov.args,
       ci.style = ci.style,
+      p_adjust = p.adjust,
       ...
     )
 
@@ -832,10 +859,11 @@ get_model_data <- function(model,
 }
 
 
+#' @importFrom insight has_intercept
 one_par <- function(model) {
   tryCatch(
     {
-      length(stats::coef(model)) <= 2
+      length(stats::coef(model)) < 2 & !insight::has_intercept(model)
     },
     error = function(x) { FALSE }
   )
