@@ -5,11 +5,10 @@ if (suppressWarnings(
   require("sjPlot") &&
   require("sjmisc") &&
   require("lme4") &&
-  require("glmmTMB")
+  require("glmmTMB") &&
+  interactive()
 )) {
 
-  context("sjPlot, tab_model type std")
-
   data(sleepstudy)
   data(Salamanders)
   data(iris)
@@ -33,7 +32,7 @@ if (suppressWarnings(
   })
 
   test_that("tab_model", {
-    expect_warning(tab_model(m1, m2, m3, m4))
+    tab_model(m1, m2, m3, m4)
   })
 
   test_that("tab_model, check shows", {
